# -*- coding: UTF-8 -*-

#   icd_congfig_save.py    2022.4.10  kita
#!!   iCADの環境設定保存、読み込みScript

#   必要なFile

#   履歴
# 2023.3.18     C:/icadsx/USER/Favorites/をフォルダーごと保存、復元


import tkinter as tk            # 
from tkinter import filedialog
#import tkinter.ttk as ttk       # ComboBoxを使うのに必要
import sys
import os
import numpy as np
import codecs
import shutil
#import re
import glob


def push_save():    # iCAD環境設定ファイル保存
    personal_fld = e_fld.get()
    if personal_fld[-1:] != '/':
        personal_fld = personal_fld + '/'
    if not os.path.exists(personal_fld):    # フォルダー存在確認
        os.makedirs(personal_fld)           # フォルダーが無いときは作る

    #print(cf_fn)

    for fp_fn in cf_fn:
        if os.path.isdir(fp_fn):    # もしフォルダー名なら 2023.3.18追記
            fld_nm= os.path.dirname(fp_fn)
            tmp= fld_nm.split('/') 
            tmp_fld= personal_fld+tmp[-1]
            #print(tmp_fld)    #!!!!!
            if os.path.exists(tmp_fld):
                shutil.rmtree(tmp_fld)
                
            print('\n   %s Folderを %sにコピーしました' % (fp_fn, tmp_fld)) 
            shutil.copytree(fp_fn, tmp_fld)   # Folderごとcopyする

            continue

        if fp_fn.find('*'):     # C:\icadsx\HOME\<User_name>\SHORTCUT*
            files = glob.glob(fp_fn)
            for file in files:
                print('\n   %s を %sにコピーしました' % (file, personal_fld)) 
                shutil.copy(file, personal_fld)        

        else:
            print('\n   %s を %sにコピーしました' % (fp_fn, personal_fld)) 
            shutil.copy(fp_fn, personal_fld)        



def push_restore():  # iCAD環境設定ファイル復元
    yn = input('\n   本当に復元していいですか？  y/n(Enter)\007     ')
    if yn == "n" or yn == '':
        print('\n   復元を中止しました\n')
        return
     
    personal_fld = e_fld.get()
    nm = os.path.basename(personal_fld)    #名前
    yn = input('\n   あなたは本当に %s さんですか？  y/n(Enter)\007     ' % nm)
    if yn == "n" or yn == '':
        print('\n   復元を中止しました\n')
        return
    

    if personal_fld[-1:] != '/':
        personal_fld = personal_fld + '/'
    if not os.path.exists(personal_fld):    # フォルダー存在確認
        print('\n   指定されたフォルダーが存在しません\007\n')
        return
    for fp_fn in cf_fn:
        fn = os.path.basename(fp_fn)
        restore_fld = os.path.dirname(fp_fn)

        #########################
        if os.path.isdir(fp_fn):    # フォルダーなら
            fld_nm= os.path.dirname(fp_fn)
            tmp= fld_nm.split('/') 
            tmp_fld= personal_fld+tmp[-1]
            print('\n   %s を %s にフォルダーコピーします' % (tmp_fld, fp_fn))  #!!!!
            if os.path.exists(fp_fn):
                shutil.rmtree(fp_fn)
            shutil.copytree(tmp_fld, fp_fn)
            continue

        if restore_fld[-1:] != '/':
            restore_fld = restore_fld + '/'

        files = glob.glob(personal_fld + fn)

        for file in files:
            print('\n   %s を %s にコピーしました' % (file, restore_fld)) 
            shutil.copy(file, restore_fld)        
    

def push_dialog():    # Folder指定
    global personal_fld
    iDir = os.path.abspath(os.path.dirname(personal_fld))
    tmp = filedialog.askdirectory(initialdir=iDir)
    if tmp == '':
        return

    personal_fld = tmp
    e_fld.delete(0,tk.END)
    e_fld.insert(0,personal_fld)

def read_ent(read_fn): # Entry設定値の読み込み(起動時)
    fp = codecs.open(read_fn, 'r', 'utf-8')
    lines = fp.readlines()
    fp.close() 
    ss_ent = lines[0].rstrip() # 行末の改行削除 
    
    return ss_ent



def on_closing():       # 終了時の処理
    # Entry保存
    ss_ent = e_fld.get()
    fp = codecs.open(entry_fld, 'w', 'utf-8')
    fp.write(ss_ent)
    fp.close()
    print('\n   %s に書き込みました' % entry_fld)
    
    root.destroy()



# 設定ファイル icd_config_save.ini 読み込み
def read_ini(save_fn):
    # Log In User Name取得
    user_name = os.getlogin()
    #print(user_name)
    fp = codecs.open(save_fn, 'r', 'utf-8')
    lines = fp.readlines()
    fp.close()
    cf_fn = [] 
    i = 0
    for line in lines:
        line = line.rstrip()    # 行末の改行削除
        if line.find('#') > -1:  # #が含まれてるなら
            continue
        else:
            if line.find('<User_name>'):
                cf_fn.append(line.replace('<User_name>', user_name))
            else:
                cf_fn.append(line)
            i += 1
    #print(cf_fn)
    return cf_fn   


#------------------------------------------------------ 
#   起動時の処理
#------------------------------------------------------
# iCAD環境設定ファイル読み込み
(fn, ext)= os.path.splitext(__file__) # (icd_config_save,py) 拡張子抽出 
fn= fn + '.ini'
#print(fn); quit()   ######

cf_fn = read_ini(fn)
#cf_fn = read_ini('icd_config_save_.ini')

# Entry読み込み
entry_fld = 'c:\ICADSX\icd_config_save.txt'
if os.path.exists(entry_fld):      # fnが存在するなら
    personal_fld = read_ent(entry_fld)
else:
    personal_fld = 'y:/Personal/馬田'



#************************************
# ボタン等の部品配置
#************************************
nl = 2
root = tk.Tk()
root.attributes("-topmost", True)    # 常に前面に表示
root.configure(bg='RoyalBlue4')
py_fn = os.path.basename(__file__)
root.title(py_fn)   #タイトル
#root.title('Personal環境保存')   #タイトル
root.geometry('240x%d+1000+0' % (nl*30))


btn_bcol = 'grey21'     #ボタン背景色
btn_tcol = 'white'      #ボタン文字色
label_bcol = 'khaki3'   #ラベル背景色
label_tcol = 'black'   #ラベル文字色
e_bcol = 'khaki4'

x00 = 10; y00 = 4
dx = 100;  dy = 28
wdth = 10 

#path0 = 'y:\\Personal\\'
#path1 = path0 + 'umada\\'

ss = 'Folder指定'; num = 0    # Buttn
btn = tk.Button(root,text = ss, command = push_dialog, bg=btn_bcol,fg=btn_tcol) #ボタンの作成
btn.place(x=x00+160, y=num*dy)

num = 0
e_fld = tk.Entry(root, width=25, bg=e_bcol)  # エントリー部品の生成
e_fld.place(x=x00, y=num*dy+5)
e_fld.insert(0,personal_fld)       # エントリーの中身を設定

ss = '保存実行'; num = 1    # Buttn
btn = tk.Button(root,text = ss, command = push_save, bg=btn_bcol,fg=btn_tcol) #ボタンの作成
btn.place(x=x00+80, y=num*dy)

ss = '復元実行'; num = 1    # Buttn
btn = tk.Button(root,text = ss, command = push_restore, bg='orange',fg='black') #ボタンの作成
btn.place(x=x00, y=num*dy)


root.protocol("WM_DELETE_WINDOW", on_closing) #終了時処理
root.mainloop()



